@@ -1,5 +1,5 @@
 #' @importFrom clinUtils clinColors clinShapes clinLinetypes
-.onAttach <- function(libname, pkgname) {
+.onLoad <- function(libname, pkgname) {
 	options(clinDataReview.colors = clinColors)
 	options(clinDataReview.shapes = clinShapes)
 	options(clinDataReview.linetypes = clinLinetypes)
